index.BitmapIndex

|  | ## Cheshire3 Object Model: Class BitmapIndex

Module index :: Class BitmapIndex

## Class BitmapIndex
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
            baseObjects.Index --+
                                |
                      SimpleIndex --+
                                    |
                                   BitmapIndex

Instance Methods

__init__(self, session, a, b)
serialise_terms(self, termid, terms, recs=0, occs=0)
deserialise_terms(self, data, prox=1)
merge_terms(self, structTerms, newTerms, op="replace", recs=0, occs=0)
construct_item(self, session, term)
construct_resultSet(self, session, terms, queryHash={})
Inherited from `SimpleIndex`: `begin_indexing`, `commit_indexing`, `delete_record`, `extract_data`, `index_record`, `scan`, `search`, `store_terms` Inherited from `SimpleIndex` (private): `_handleConfigNode`, `_mergeHash`, `_processChain`, `_processRecord` Inherited from `baseObjects.Index`: `sort` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `SimpleIndex`: `currentFullPath`, `currentPath`, `debug`, `indexingData`, `indexingTerm`, `sources`, `storeOrig`, `xPathAllAbsolute`, `xPathAttributesRequired`, `xPathsNormalized` Inherited from `baseObjects.Index`: `indexStore` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, a, b) (Constructor) | source code
Overrides: SimpleIndex.__init__

### serialise_terms(self, termid, terms, recs=0, occs=0) | source code
Overrides: SimpleIndex.serialise_terms

### deserialise_terms(self, data, prox=1) | source code
Overrides: SimpleIndex.deserialise_terms

### merge_terms(self, structTerms, newTerms, op="replace", recs=0, occs=0) | source code
Overrides: SimpleIndex.merge_terms

### construct_item(self, session, term) | source code
Overrides: SimpleIndex.construct_item

### construct_resultSet(self, session, terms, queryHash={}) | source code
Overrides: SimpleIndex.construct_resultSet